@@ -21,11 +21,9 @@ class TimeoutMgr(object):
                 # 已经存在的话，就返回了
                 return
 
-        deadline = time.time() + interval
-
         def callback_wrapper():
             # 这样可以让timeout及时变成None
-            if self.timeout and deadline == self.timeout.deadline:
+            if self.timeout == timeout:
                 # 必须要确定，这次调用就是这个timeout引起的
                 self.timeout = None
                 # 先执行这里
@@ -35,7 +33,7 @@ class TimeoutMgr(object):
                     self.set(interval, callback, repeat=repeat)
                 return result
 
-        self.timeout = ioloop.IOLoop.current().add_timeout(deadline, callback_wrapper)
+        self.timeout = timeout = ioloop.IOLoop.current().add_timeout(time.time() + interval, callback_wrapper)
 
     def clear(self):
         """
